@@ -11,7 +11,8 @@ import warnings
 from contextlib import contextmanager
 
 from jupyter_core.paths import jupyter_config_dir
-from traitlets.config import Config, ConfigFileNotFound, JSONFileConfigLoader
+from traitlets.config import Config
+from traitlets.config.loader import ConfigFileNotFound, JSONFileConfigLoader
 
 # Length of the salt in nr of hex chars, which implies salt_len * 4
 # bits of randomness.
