@@ -1,24 +1,24 @@
-# coding: utf-8
 """Utilities for installing extensions"""
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
+
+import logging
 import os
 import sys
+import typing as t
 
 from jupyter_core.application import JupyterApp
-from jupyter_core.paths import ENV_CONFIG_PATH
-from jupyter_core.paths import jupyter_config_dir
-from jupyter_core.paths import SYSTEM_CONFIG_PATH
+from jupyter_core.paths import ENV_CONFIG_PATH, SYSTEM_CONFIG_PATH, jupyter_config_dir
 from tornado.log import LogFormatter
 from traitlets import Bool
 
 from jupyter_server._version import __version__
 from jupyter_server.extension.config import ExtensionConfigManager
-from jupyter_server.extension.manager import ExtensionManager
-from jupyter_server.extension.manager import ExtensionPackage
+from jupyter_server.extension.manager import ExtensionManager, ExtensionPackage
 
 
-def _get_config_dir(user=False, sys_prefix=False):
+def _get_config_dir(user: bool = False, sys_prefix: bool = False) -> str:
     """Get the location of config files for the current context
 
     Returns the string to the environment
@@ -41,7 +41,9 @@ def _get_config_dir(user=False, sys_prefix=False):
     return extdir
 
 
-def _get_extmanager_for_context(write_dir="jupyter_server_config.d", user=False, sys_prefix=False):
+def _get_extmanager_for_context(
+    write_dir: str = "jupyter_server_config.d", user: bool = False, sys_prefix: bool = False
+) -> tuple[str, ExtensionManager]:
     """Get an extension manager pointing at the current context
 
     Returns the path to the current context and an ExtensionManager object.
@@ -70,7 +72,7 @@ class ArgumentConflict(ValueError):
     pass
 
 
-_base_flags = {}
+_base_flags: dict[str, t.Any] = {}
 _base_flags.update(JupyterApp.flags)
 _base_flags.pop("y", None)
 _base_flags.pop("generate-config", None)
@@ -113,14 +115,14 @@ _base_flags.update(
 )
 _base_flags["python"] = _base_flags["py"]
 
-_base_aliases = {}
+_base_aliases: dict[str, t.Any] = {}
 _base_aliases.update(JupyterApp.aliases)
 
 
 class BaseExtensionApp(JupyterApp):
     """Base extension installer app"""
 
-    _log_formatter_cls = LogFormatter
+    _log_formatter_cls = LogFormatter  # type:ignore[assignment]
     flags = _base_flags
     aliases = _base_aliases
     version = __version__
@@ -129,12 +131,12 @@ class BaseExtensionApp(JupyterApp):
     sys_prefix = Bool(True, config=True, help="Use the sys.prefix as the prefix")
     python = Bool(False, config=True, help="Install from a Python package")
 
-    def _log_format_default(self):
+    def _log_format_default(self) -> str:
         """A default format for messages"""
         return "%(message)s"
 
     @property
-    def config_dir(self):
+    def config_dir(self) -> str:  # type:ignore[override]
         return _get_config_dir(user=self.user, sys_prefix=self.sys_prefix)
 
 
@@ -151,8 +153,12 @@ RED_X = "\033[31m X\033[0m" if os.name != "nt" else " X"
 
 
 def toggle_server_extension_python(
-    import_name, enabled=None, parent=None, user=False, sys_prefix=True
-):
+    import_name: str,
+    enabled: bool | None = None,
+    parent: t.Any = None,
+    user: bool = False,
+    sys_prefix: bool = True,
+) -> None:
     """Toggle the boolean setting for a given server extension
     in a Jupyter config file.
     """
@@ -216,11 +222,14 @@ flags.update(
 flags["python"] = flags["py"]
 
 
+_desc = "Enable/disable a server extension using frontend configuration files."
+
+
 class ToggleServerExtensionApp(BaseExtensionApp):
     """A base class for enabling/disabling extensions"""
 
     name = "jupyter server extension enable/disable"
-    description = "Enable/disable a server extension using frontend configuration files."
+    description = _desc
 
     flags = flags
 
@@ -228,7 +237,7 @@ class ToggleServerExtensionApp(BaseExtensionApp):
     _toggle_pre_message = ""
     _toggle_post_message = ""
 
-    def toggle_server_extension(self, import_name):
+    def toggle_server_extension(self, import_name: str) -> None:
         """Change the status of a named server extension.
 
         Uses the value of `self._toggle_value`.
@@ -245,29 +254,30 @@ class ToggleServerExtensionApp(BaseExtensionApp):
             user=self.user, sys_prefix=self.sys_prefix
         )
         try:
-            self.log.info("{}: {}".format(self._toggle_pre_message.capitalize(), import_name))
-            self.log.info("- Writing config: {}".format(config_dir))
+            self.log.info(f"{self._toggle_pre_message.capitalize()}: {import_name}")
+            self.log.info(f"- Writing config: {config_dir}")
             # Validate the server extension.
-            self.log.info("    - Validating {}...".format(import_name))
+            self.log.info(f"    - Validating {import_name}...")
             # Interface with the Extension Package and validate.
             extpkg = ExtensionPackage(name=import_name)
             extpkg.validate()
             version = extpkg.version
-            self.log.info("      {} {} {}".format(import_name, version, GREEN_OK))
+            self.log.info(f"      {import_name} {version} {GREEN_OK}")
 
             # Toggle extension config.
             config = extension_manager.config_manager
-            if self._toggle_value is True:
-                config.enable(import_name)
-            else:
-                config.disable(import_name)
+            if config:
+                if self._toggle_value is True:
+                    config.enable(import_name)
+                else:
+                    config.disable(import_name)
 
             # If successful, let's log.
-            self.log.info("    - Extension successfully {}.".format(self._toggle_post_message))
+            self.log.info(f"    - Extension successfully {self._toggle_post_message}.")
         except Exception as err:
-            self.log.info("     {} Validation failed: {}".format(RED_X, err))
+            self.log.info(f"     {RED_X} Validation failed: {err}")
 
-    def start(self):
+    def start(self) -> None:
         """Perform the App's actions as configured"""
         if not self.extra_args:
             sys.exit("Please specify a server extension/package to enable or disable")
@@ -285,7 +295,7 @@ class EnableServerExtensionApp(ToggleServerExtensionApp):
     Usage
         jupyter server extension enable [--system|--sys-prefix]
     """
-    _toggle_value = True
+    _toggle_value = True  # type:ignore[assignment]
     _toggle_pre_message = "enabling"
     _toggle_post_message = "enabled"
 
@@ -300,7 +310,7 @@ class DisableServerExtensionApp(ToggleServerExtensionApp):
     Usage
         jupyter server extension disable [--system|--sys-prefix]
     """
-    _toggle_value = False
+    _toggle_value = False  # type:ignore[assignment]
     _toggle_pre_message = "disabling"
     _toggle_post_message = "disabled"
 
@@ -312,7 +322,7 @@ class ListServerExtensionsApp(BaseExtensionApp):
     version = __version__
     description = "List all server extensions known by the configuration system"
 
-    def list_server_extensions(self):
+    def list_server_extensions(self) -> None:
         """List all enabled and disabled server extensions, by config path
 
         Enabled extensions are validated, potentially generating warnings.
@@ -324,24 +334,34 @@ class ListServerExtensionsApp(BaseExtensionApp):
         )
 
         for option in configurations:
-            config_dir, ext_manager = _get_extmanager_for_context(**option)
-            self.log.info("Config dir: {}".format(config_dir))
-            for name, extension in ext_manager.extensions.items():
-                enabled = extension.enabled
+            config_dir = _get_config_dir(**option)
+            self.log.info(f"Config dir: {config_dir}")
+            write_dir = "jupyter_server_config.d"
+            config_manager = ExtensionConfigManager(
+                read_config_path=[config_dir],
+                write_config_dir=os.path.join(config_dir, write_dir),
+            )
+            jpserver_extensions = config_manager.get_jpserver_extensions()
+            for name, enabled in jpserver_extensions.items():
                 # Attempt to get extension metadata
-                self.log.info("    {} {}".format(name, GREEN_ENABLED if enabled else RED_DISABLED))
+                self.log.info(f"    {name} {GREEN_ENABLED if enabled else RED_DISABLED}")
                 try:
-                    self.log.info("    - Validating {}...".format(name))
+                    self.log.info(f"    - Validating {name}...")
+                    extension = ExtensionPackage(name=name, enabled=enabled)
                     if not extension.validate():
-                        raise ValueError("validation failed")
+                        msg = "validation failed"
+                        raise ValueError(msg)
                     version = extension.version
-                    self.log.info("      {} {} {}".format(name, version, GREEN_OK))
+                    self.log.info(f"      {name} {version} {GREEN_OK}")
                 except Exception as err:
-                    self.log.warning("      {} {}".format(RED_X, err))
+                    exc_info = False
+                    if int(self.log_level) <= logging.DEBUG:  # type:ignore[call-overload]
+                        exc_info = True
+                    self.log.warning(f"      {RED_X} {err}", exc_info=exc_info)
             # Add a blank line between paths.
             self.log.info("")
 
-    def start(self):
+    def start(self) -> None:
         """Perform the App's actions as configured"""
         self.list_server_extensions()
 
@@ -358,18 +378,18 @@ class ServerExtensionApp(BaseExtensionApp):
 
     name = "jupyter server extension"
     version = __version__
-    description = "Work with Jupyter server extensions"
+    description: str = "Work with Jupyter server extensions"
     examples = _examples
 
-    subcommands = dict(
-        enable=(EnableServerExtensionApp, "Enable a server extension"),
-        disable=(DisableServerExtensionApp, "Disable a server extension"),
-        list=(ListServerExtensionsApp, "List server extensions"),
-    )
+    subcommands: dict = {
+        "enable": (EnableServerExtensionApp, "Enable a server extension"),
+        "disable": (DisableServerExtensionApp, "Disable a server extension"),
+        "list": (ListServerExtensionsApp, "List server extensions"),
+    }
 
-    def start(self):
+    def start(self) -> None:
         """Perform the App's actions as configured"""
-        super(ServerExtensionApp, self).start()
+        super().start()
 
         # The above should have called a subcommand and raised NoStart; if we
         # get here, it didn't, so we should self.log.info a message.
