@@ -12,7 +12,7 @@ from nbformat import from_dict
 from tornado import web
 from tornado.log import app_log
 
-from jupyter_server.auth import authorized
+from jupyter_server.auth.decorator import authorized
 
 from ..base.handlers import FilesRedirectHandler, JupyterHandler, path_regex
 
