@@ -33,8 +33,8 @@ from .manager import AsyncContentsManager, ContentsManager, copy_pat
 try:
     from os.path import samefile
 except ImportError:
-    # windows + py2
-    from jupyter_server.utils import samefile_simple as samefile
+    # windows
+    from jupyter_server.utils import samefile_simple as samefile  # type:ignore[assignment]
 
 _script_exporter = None
 
@@ -48,10 +48,9 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
     @default("root_dir")
     def _default_root_dir(self):
-        try:
-            return self.parent.root_dir
-        except AttributeError:
+        if not self.parent:
             return os.getcwd()
+        return self.parent.root_dir
 
     @validate("root_dir")
     def _validate_root_dir(self, proposal):
@@ -65,6 +64,8 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
     @default("preferred_dir")
     def _default_preferred_dir(self):
+        if not self.parent:
+            return ""
         try:
             value = self.parent.preferred_dir
             if value == self.parent.root_dir:
@@ -457,7 +458,6 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
             raise web.HTTPError(400, "No file type provided")
         if "content" not in model and model["type"] != "directory":
             raise web.HTTPError(400, "No file content provided")
-
         os_path = self._get_os_path(path)
 
         if not self.allow_hidden and is_hidden(os_path, self.root_dir):
@@ -677,11 +677,13 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
         """
         try:
             if platform.system() == "Darwin":
-                # retuns the size of the folder in KB
-                result = subprocess.run(["du", "-sk", path], capture_output=True).stdout.split()
+                # returns the size of the folder in KB
+                result = subprocess.run(
+                    ["du", "-sk", path], capture_output=True, check=True
+                ).stdout.split()
             else:
                 result = subprocess.run(
-                    ["du", "-s", "--block-size=1", path], capture_output=True
+                    ["du", "-s", "--block-size=1", path], capture_output=True, check=True
                 ).stdout.split()
 
             self.log.info(f"current status of du command {result}")
@@ -704,7 +706,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
         units = ["Bytes", "KB", "MB", "GB", "TB", "PB"]
         order = int(math.log2(size) / 10) if size else 0
 
-        return "{:.4g} {}".format(size / (1 << (order * 10)), units[order])
+        return f"{size / (1 << (order * 10)):.4g} {units[order]}"
 
 
 class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, AsyncContentsManager):
@@ -1136,11 +1138,13 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         """
         try:
             if platform.system() == "Darwin":
-                # retuns the size of the folder in KB
-                result = subprocess.run(["du", "-sk", path], capture_output=True).stdout.split()
+                # returns the size of the folder in KB
+                result = subprocess.run(
+                    ["du", "-sk", path], capture_output=True, check=True
+                ).stdout.split()
             else:
                 result = subprocess.run(
-                    ["du", "-s", "--block-size=1", path], capture_output=True
+                    ["du", "-s", "--block-size=1", path], capture_output=True, check=True
                 ).stdout.split()
 
             self.log.info(f"current status of du command {result}")
@@ -1163,4 +1167,4 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         units = ["Bytes", "KB", "MB", "GB", "TB", "PB"]
         order = int(math.log2(size) / 10) if size else 0
 
-        return "{:.4g} {}".format(size / (1 << (order * 10)), units[order])
+        return f"{size / (1 << (order * 10)):.4g} {units[order]}"
