@@ -14,7 +14,7 @@ except ImportError:
 from jupyter_core.utils import ensure_async
 from tornado import web
 
-from jupyter_server.auth import authorized
+from jupyter_server.auth.decorator import authorized
 from jupyter_server.base.handlers import APIHandler, JupyterHandler, path_regex
 from jupyter_server.utils import url_escape, url_path_join
 
@@ -353,7 +353,7 @@ class NotebooksRedirectHandler(JupyterHandler):
 class TrustNotebooksHandler(JupyterHandler):
     """Handles trust/signing of notebooks"""
 
-    @web.authenticated
+    @web.authenticated  # type:ignore[misc]
     @authorized(resource=AUTH_RESOURCE)
     async def post(self, path=""):
         """Trust a notebook by path."""
