@@ -1,14 +1,15 @@
 """An implementation of a kernel connection."""
+from __future__ import annotations
+
 import asyncio
 import json
 import time
+import typing as t
 import weakref
 from concurrent.futures import Future
 from textwrap import dedent
-from typing import Dict as Dict_t
-from typing import MutableSet
 
-from jupyter_client import protocol_version as client_protocol_version
+from jupyter_client import protocol_version as client_protocol_version  # type:ignore[attr-defined]
 from tornado import gen, web
 from tornado.ioloop import IOLoop
 from tornado.websocket import WebSocketClosedError
@@ -85,6 +86,8 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
         ),
     )
 
+    websocket_handler = Instance(KernelWebsocketHandler)
+
     @property
     def write_message(self):
         """Alias to the websocket handler's write_message method."""
@@ -93,8 +96,8 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
     # class-level registry of open sessions
     # allows checking for conflict on session-id,
     # which is used as a zmq identity and must be unique.
-    _open_sessions: Dict_t[str, KernelWebsocketHandler] = {}
-    _open_sockets: MutableSet["ZMQChannelsWebsocketConnection"] = weakref.WeakSet()
+    _open_sessions: dict[str, KernelWebsocketHandler] = {}
+    _open_sockets: t.MutableSet[ZMQChannelsWebsocketConnection] = weakref.WeakSet()
 
     _kernel_info_future: Future
     _close_future: Future
@@ -125,7 +128,7 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
     # Queue of (time stamp, byte count)
     # Allows you to specify that the byte count should be lowered
     # by a delta amount at some point in the future.
-    _iopub_window_byte_queue = List([])
+    _iopub_window_byte_queue: List[t.Any] = List([])
 
     @classmethod
     async def close_all(cls):
@@ -283,7 +286,9 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
         if (
             self.kernel_id in self.multi_kernel_manager
         ):  # only update open sessions if kernel is actively managed
-            self._open_sessions[self.session_key] = self.websocket_handler
+            self._open_sessions[self.session_key] = t.cast(
+                KernelWebsocketHandler, self.websocket_handler
+            )
 
     async def prepare(self):
         """Prepare a kernel connection."""
@@ -450,8 +455,8 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
                 "header": None,
             }
         else:
-            if isinstance(ws_msg, bytes):
-                msg = deserialize_binary_message(ws_msg)
+            if isinstance(ws_msg, bytes):  # type:ignore[unreachable]
+                msg = deserialize_binary_message(ws_msg)  # type:ignore[unreachable]
             else:
                 msg = json.loads(ws_msg)
             msg_list = []
@@ -468,7 +473,7 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
         if am:
             msg["header"] = self.get_part("header", msg["header"], msg_list)
             assert msg["header"] is not None
-            if msg["header"]["msg_type"] not in am:
+            if msg["header"]["msg_type"] not in am:  # type:ignore[unreachable]
                 self.log.warning(
                     'Received message of type "%s", which is not allowed. Ignoring.'
                     % msg["header"]["msg_type"]
@@ -623,11 +628,7 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
         if protocol_version != client_protocol_version:
             self.session.adapt_version = int(protocol_version.split(".")[0])
             self.log.info(
-                "Adapting from protocol version {protocol_version} (kernel {kernel_id}) to {client_protocol_version} (client).".format(
-                    protocol_version=protocol_version,
-                    kernel_id=self.kernel_id,
-                    client_protocol_version=client_protocol_version,
-                )
+                f"Adapting from protocol version {protocol_version} (kernel {self.kernel_id}) to {client_protocol_version} (client)."
             )
         if not self._kernel_info_future.done():
             self._kernel_info_future.set_result(info)
@@ -703,7 +704,7 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
                     )
                     self.write_stderr(
                         dedent(
-                            """\
+                            f"""\
                     IOPub message rate exceeded.
                     The Jupyter server will temporarily stop sending output
                     to the client in order to avoid crashing it.
@@ -711,11 +712,9 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
                     `--ServerApp.iopub_msg_rate_limit`.
 
                     Current values:
-                    ServerApp.iopub_msg_rate_limit={} (msgs/sec)
-                    ServerApp.rate_limit_window={} (secs)
-                    """.format(
-                                self.iopub_msg_rate_limit, self.rate_limit_window
-                            )
+                    ServerApp.iopub_msg_rate_limit={self.iopub_msg_rate_limit} (msgs/sec)
+                    ServerApp.rate_limit_window={self.rate_limit_window} (secs)
+                    """
                         ),
                         msg["parent_header"],
                     )
@@ -734,7 +733,7 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
                     )
                     self.write_stderr(
                         dedent(
-                            """\
+                            f"""\
                     IOPub data rate exceeded.
                     The Jupyter server will temporarily stop sending output
                     to the client in order to avoid crashing it.
@@ -742,11 +741,9 @@ class ZMQChannelsWebsocketConnection(BaseKernelWebsocketConnection):
                     `--ServerApp.iopub_data_rate_limit`.
 
                     Current values:
-                    ServerApp.iopub_data_rate_limit={} (bytes/sec)
-                    ServerApp.rate_limit_window={} (secs)
-                    """.format(
-                                self.iopub_data_rate_limit, self.rate_limit_window
-                            )
+                    ServerApp.iopub_data_rate_limit={self.iopub_data_rate_limit} (bytes/sec)
+                    ServerApp.rate_limit_window={self.rate_limit_window} (secs)
+                    """
                         ),
                         msg["parent_header"],
                     )
