@@ -14,7 +14,7 @@ try:
     import sqlite3
 except ImportError:
     # fallback on pysqlite2 if Python was build without sqlite
-    from pysqlite2 import dbapi2 as sqlite3  # type:ignore
+    from pysqlite2 import dbapi2 as sqlite3  # type:ignore[no-redef]
 
 from dataclasses import dataclass, fields
 
@@ -81,7 +81,7 @@ class KernelSessionRecord:
     def update(self, other: "KernelSessionRecord") -> None:
         """Updates in-place a kernel from other (only accepts positive updates"""
         if not isinstance(other, KernelSessionRecord):
-            msg = "'other' must be an instance of KernelSessionRecord."
+            msg = "'other' must be an instance of KernelSessionRecord."  # type:ignore[unreachable]
             raise TypeError(msg)
 
         if other.kernel_id and self.kernel_id and other.kernel_id != self.kernel_id:
@@ -135,7 +135,7 @@ class KernelSessionRecordList:
         """
         if isinstance(record, str):
             for r in self._records:
-                if record == r.kernel_id or record == r.session_id:
+                if record in (r.kernel_id, r.session_id):
                     return r
         elif isinstance(record, KernelSessionRecord):
             for r in self._records:
@@ -461,6 +461,13 @@ class SessionManager(LoggingConfigurable):
         query = "UPDATE session SET %s WHERE session_id=?" % (", ".join(sets))  # noqa
         self.cursor.execute(query, [*list(kwargs.values()), session_id])
 
+        if hasattr(self.kernel_manager, "update_env"):
+            self.cursor.execute(
+                "SELECT path, name, kernel_id FROM session WHERE session_id=?", [session_id]
+            )
+            path, name, kernel_id = self.cursor.fetchone()
+            self.kernel_manager.update_env(kernel_id=kernel_id, env=self.get_kernel_env(path, name))
+
     async def kernel_culled(self, kernel_id: str) -> bool:
         """Checks if the kernel is still considered alive and returns true if its not found."""
         return kernel_id not in self.kernel_manager
